summaryrefslogtreecommitdiffstats
path: root/chrome/browser/app_controller_mac.mm
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/app_controller_mac.mm')
-rw-r--r--chrome/browser/app_controller_mac.mm4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/app_controller_mac.mm b/chrome/browser/app_controller_mac.mm
index 3895ceb..ed1640f 100644
--- a/chrome/browser/app_controller_mac.mm
+++ b/chrome/browser/app_controller_mac.mm
@@ -359,14 +359,14 @@ class AppControllerProfileObserver : public ProfileInfoCacheObserver {
size_t num_browsers = chrome::GetTotalBrowserCount();
// Initiate a shutdown (via chrome::CloseAllBrowsers()) if we aren't
// already shutting down.
if (!browser_shutdown::IsTryingToQuit()) {
content::NotificationService::current()->Notify(
chrome::NOTIFICATION_CLOSE_ALL_BROWSERS_REQUEST,
content::NotificationService::AllSources(),
content::NotificationService::NoDetails());
- chrome::CloseAllBrowsers();
+ chrome::CloseAllBrowsersAndQuit();
}
return num_browsers == 0 ? YES : NO;
@@ -359,14 +359,14 @@ class AppControllerProfileObserver : public ProfileInfoCacheObserver {
size_t num_browsers = chrome::GetTotalBrowserCount();
- // Initiate a shutdown (via chrome::CloseAllBrowsers()) if we aren't
+ // Initiate a shutdown (via chrome::CloseAllBrowsersAndQuit()) if we aren't
// already shutting down.
if (!browser_shutdown::IsTryingToQuit()) {